# -*- python -*-

# Copyright (C) 1998,1999,2000 by the Free Software Foundation, Inc.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software 
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""This module contains your site-specific settings.

From a brand new distribution it should be copied to mm_cfg.py.  If you
already have an mm_cfg.py, be careful to add in only the new settings you
want.  Mailman's installation procedure will never overwrite your mm_cfg.py
file.

The complete set of distributed defaults, with documentation, are in the file
Defaults.py.  In mm_cfg.py, override only those you want to change, after the

  from Defaults import *

line (see below).

Note that these are just default settings; many can be overridden via the
administrator and user interfaces on a per-list or per-user basis.

"""

###############################################
# Here's where we get the distributed defaults.

from Defaults import *

##################################################
# Put YOUR site-specific settings below this line.

import os, sys, site


def init(domain):
    global DEFAULT_HOST_NAME, DEFAULT_URL
    global PUBLIC_ARCHIVE_URL, PRIVATE_ARCHIVE_URL
    global MAILMAN_OWNER, IMAGE_LOGOS, VIRTUAL_HOST_OVERVIEW
    global LDAP_SERVER, LDAP_BIND_DN

    global VAR_PREFIX, LIST_DATA_DIR, LOG_DIR, LOCK_DIR, DATA_DIR, QUEUE_DIR
    global SPAM_DIR, PUBLIC_ARCHIVE_FILE_DIR, PRIVATE_ARCHIVE_FILE_DIR
    global SITE_PW_FILE

    DEFAULT_HOST_NAME   = domain
    DEFAULT_URL         = 'http://YOUR_WEBSERVER/mailman/%s/' % domain
    PUBLIC_ARCHIVE_URL  = '/pipermail/%s' % domain
    PRIVATE_ARCHIVE_URL = '/mailman/%s/private' % domain
    MAILMAN_OWNER       = 'mailman-owner@%s' % domain
    IMAGE_LOGOS         = '/images/mailman/'
    VIRTUAL_HOST_OVERVIEW = 0
    LDAP_SERVER         = 'YOUR_LDAP_SERVER'
    LDAP_BIND_DN        = 'YOUR_BASE_DN'

    VAR_PREFIX		= os.path.join('/var/lib/mailman', domain)
    LIST_DATA_DIR       = os.path.join(VAR_PREFIX, 'lists')
    LOG_DIR             = os.path.join(VAR_PREFIX, 'logs')
    LOCK_DIR            = os.path.join(VAR_PREFIX, 'locks')
    DATA_DIR            = os.path.join(VAR_PREFIX, 'data')
    QUEUE_DIR           = os.path.join(VAR_PREFIX, 'qfiles')
    SPAM_DIR            = os.path.join(VAR_PREFIX, 'spam')
    PUBLIC_ARCHIVE_FILE_DIR  = os.path.join(VAR_PREFIX, 'archives', 'public')
    PRIVATE_ARCHIVE_FILE_DIR = os.path.join(VAR_PREFIX, 'archives', 'private')

    SITE_PW_FILE = os.path.join(DATA_DIR, 'adm.pw')


if not os.environ.has_key('DOMAIN'):
    sys.exit('The environment variable DOMAIN must be set')

init(os.environ['DOMAIN']) # FIXME -- regex

if not os.path.isdir(VAR_PREFIX):
    sys.exit(VAR_PREFIX + ' must exist.')

